.. dropdown:: Installation

   Choose your preferred installation method. We recommend installing TidyMS2 in a virtual environment.

   .. tab-set::

      .. tab-item:: pip

         .. code-block:: shell
      
            pip install tidyms2

      .. tab-item:: uv

         .. code-block:: shell
      
            uv pip install tidyms2